@@ -294,7 +294,9 @@ Ext.onReady(function () {
                      * Такое поведение нам не подходит и другого решения найдено не было.
                      * Кроме как удалять данный класс
                      * */
-                    this.parentWindow.el.removeClass('x-masked-relative');
+                    if (this.parentWindow.el) {
+                        this.parentWindow.el.removeClass('x-masked-relative');
+                    }
 
                     this.parentWindow.on('activate', this.activateChildWindow, this);
 
@@ -323,7 +325,9 @@ Ext.onReady(function () {
                 if (this.tmpModal && this.parentWindow) {
                     this.parentWindow.un('activate', this.activateChildWindow, this);
                     this.parentWindow.setDisabled(false);
-                    this.parentWindow.toFront();
+                    if (typeof this.parentWindow.toFront === 'function') {
+                        this.parentWindow.toFront();
+                    }
 
                     if (window.AppDesktop) {
                         var el = AppDesktop.getDesktop().taskbar.tbPanel.getTabWin(this.parentWindow);
